@@ -53,7 +53,7 @@ void KRadioEduca::drawButtonLabel( QPainter *p)
     int xo = 0;
     int yo = 0;
 
-    this->resize( this->width(), rh);
+    resize( width(), rh);
 
     yo = (cr.height()-rh)/2;
 
