@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2003 Anne-Marie Mahfouf <annma@kde.org>
+ * Copyright (C) 2001-2005 Anne-Marie Mahfouf <annma@kde.org>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of version 2 of the GNU General Public
@@ -34,7 +34,9 @@
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <knotifyclient.h>
 #include <kpassivepopup.h>
+#include <kpushbutton.h>
 #include <kstandarddirs.h>
 //standard C++ headers
 #include <stdlib.h>
@@ -82,6 +84,7 @@ KHangManView::KHangManView(KHangMan*parent, const char *name)
 
 	connect( charWrite, SIGNAL( textChanged(const QString &) ), this, SLOT( slotValidate(const QString &) ) );
 	connect( charWrite, SIGNAL( returnPressed() ), this, SLOT( slotTry() ) );
+	connect (guessButton, SIGNAL( clicked() ), this, SLOT( slotTry() ));
 }
 
 KHangManView::~KHangManView()
@@ -98,24 +101,19 @@ void KHangManView::slotNewGame()
 	
 	wipeout();
 	//language=Prefs::selectedLanguage();
+	QFont tFont;
 	if (language =="tg")  {
-		QFont tFont;
     		tFont.setFamily( "URW Bookman" );
-    		tFont.setPointSize( 22 );
-		missedLetters->setFont(tFont);
-		charWrite->setFont(tFont);
-		mainLabel->setFont(tFont);
 	}
 	if (language =="cs")  {
-		QFont tFont;
     		tFont.setFamily( "Arial" );
-    		tFont.setPointSize( 22 );
-		missedLetters->setFont(tFont);
-		charWrite->setFont(tFont);
-		mainLabel->setFont(tFont);
 	}
+	tFont.setPointSize( 22 );
+	missedLetters->setFont(tFont);
+	charWrite->setFont(tFont);
+	mainLabel->setFont(tFont);
 	//distinction between upper and lower case letters
-	if (levelFile == "world_capitals.txt" || levelFile == "departements.txt")
+	if (levelFile == "world_capitals.kvtml" || levelFile == "departements.kvtml")
 		upperBool = true;
 	 else upperBool = false;
 	game();
@@ -214,8 +212,14 @@ void KHangManView::slotTry()
 					if (language =="de")
 						theWord = theWord.replace(0,1, theWord.left(1).upper());
 					mainLabel->setText(theWord);
-
-					if (KMessageBox::questionYesNo(this, i18n("You are dead. Do you want to play again?")) == 3)
+					
+					//usability: change that
+					QString newGameString;
+					if (Prefs::pictures() == Prefs::EnumPictures::mild) 
+						newGameString = i18n("You lost. Do you want to play again?");
+					else
+						newGameString = i18n("You are dead. Do you want to play again?");
+					if (KMessageBox::questionYesNo(this, newGameString) == 3)
 						slotNewGame();
 					else
 						kapp->quit();
@@ -223,13 +227,69 @@ void KHangManView::slotTry()
 			}
 		}
 		else
-			KMessageBox::information (this, i18n("The letter has already been guessed."));
+		{
+			//usability: highlight it in Missed if it is there
+			if (missedL.contains(sChar)>0)
+			{
+				KPassivePopup *popup = new KPassivePopup( missedLetters, "popup" );
+  				popup->setAutoDelete( true );
+  				popup->setTimeout( 1000 );
+				popup->setView(i18n("This letter has already been guessed.") );
+				popup->show();
+				int redIndex = missedL.find(sChar,0);
+				//put the letter in red for 1 second
+				QTimer *timer = new QTimer( this);
+        			connect( timer, SIGNAL(timeout()), this, SLOT(timerDone()) );
+        			timer->start( 1000, TRUE ); // 1 second single-shot timer
+				missedLetters->setText("<qt>"+missedL.left(redIndex)+"<font color=\"#ff0000\">"+missedL[redIndex]+"</font>"+missedL.right(missedL.length()-redIndex-1)+"</qt>");
+				missedLetters->setTextFormat( QLabel::AutoText );
+				//disable any possible entry
+				charWrite->setEnabled(false);
+
+			}
+			//usability: hilight it in the word
+			if (goodWord.contains(sChar)>0)
+			{
+				KPassivePopup *popup = new KPassivePopup( mainLabel, "popup" );
+  				popup->setAutoDelete( true );
+  				popup->setTimeout( 1000 );
+				popup->setView(i18n("This letter has already been guessed.") );
+				popup->show();
+				int redIndex = goodWord.find(sChar,0);
+				QTimer *timer = new QTimer( this);
+        			connect( timer, SIGNAL(timeout()), this, SLOT(timerDoneWord()) );
+        			timer->start( 1000, TRUE ); // 1 second single-shot timer
+				//put the letter in red for 1 second
+				mainLabel->setTextFormat( QLabel::RichText );
+				mainLabel->setText("<qt>"+goodWord.left(redIndex)+"<font color=\"#ff0000\"><b>"+goodWord[redIndex]+"</b></font>"+goodWord.right(goodWord.length()-redIndex-1)+"</qt>");
+				mainLabel->setAlignment( int( QLabel::AlignCenter ) );
+				//disable any possible entry
+				charWrite->setEnabled(false);	
+			}			
+		}
 	}
 	//reset after guess...
 	charWrite->setText("");
 }
 
-void KHangManView::replaceLetters(QString sChar)
+void KHangManView::timerDone()
+{
+	missedLetters->setTextFormat( QLabel::AutoText);
+	missedLetters->setScaledContents( TRUE );
+    	missedLetters->setAlignment( int( QLabel::AlignTop ) );
+	missedLetters->setText(missedL);
+	charWrite->setEnabled(true);
+	charWrite->setFocus();
+}
+
+void KHangManView::timerDoneWord()
+{
+	mainLabel->setText(goodWord);
+	charWrite->setEnabled(true);
+	charWrite->setFocus();
+}
+
+void KHangManView::replaceLetters(const QString& sChar)
 {
 	//replace letter in the word
 	int index=0;
@@ -280,7 +340,7 @@ void KHangManView::replaceLetters(QString sChar)
 	if (b_oneLetter && b_end) allWords << sChar; 
 }
 
-bool KHangManView::containsChar(QString &sChar)
+bool KHangManView::containsChar(const QString &sChar)
 {
 	bool b = false;
 	
@@ -407,7 +467,21 @@ void KHangManView::slotSetPixmap(QPixmap& bgPix)
 {
 	QImage img = bgPix.convertToImage();
 	QPixmap bg(size());
-
+	QColor myColor;
+	if (Prefs::mode() == Prefs::EnumMode::blue)  {
+		myColor=Qt::white;
+		guessButton->setPaletteBackgroundColor( QColor( 24, 165, 16 ) );
+	}
+	else
+	if (Prefs::mode() == Prefs::EnumMode::nature) {
+		myColor=Qt::black;
+		guessButton->setPaletteBackgroundColor( QColor( 32, 141, 16 ) );
+	}
+	missedLetters->setPaletteForegroundColor(myColor);
+	TextLabel1->setPaletteForegroundColor(myColor);
+	TextLabel2->setPaletteForegroundColor(myColor);
+	TextLabel3->setPaletteForegroundColor(myColor);
+	mainLabel->setPaletteForegroundColor(myColor);
 	bg.convertFromImage(img.smoothScale( width(), height()));
 	setPaletteBackgroundPixmap(bg);
 	Frame11->setPaletteBackgroundPixmap(bg);
@@ -416,10 +490,7 @@ void KHangManView::slotSetPixmap(QPixmap& bgPix)
 	TextLabel3->setPaletteBackgroundPixmap(bg);
 	mainLabel->setPaletteBackgroundPixmap(bg);
 	missedLetters->setPaletteBackgroundPixmap(bg);
-	if (transparent)
-		pixImage->setPaletteBackgroundPixmap(bg);
-	else
-		pixImage->setBackgroundColor("#ECECEC");
+        pixImage->setPaletteBackgroundPixmap(bg);
 	charWrite->setFocus();
 	bgPixmap = bgPix;
 }
@@ -435,20 +506,18 @@ void KHangManView::slotNoBkgd()
 	Frame11->setBackgroundColor("#DCDCDC");
 	pixImage->setBackgroundColor("#ECECEC");
 	charWrite->setFocus();
+	missedLetters->setPaletteForegroundColor(Qt::black);
+	TextLabel1->setPaletteForegroundColor(Qt::black);
+	TextLabel2->setPaletteForegroundColor(Qt::black);
+	TextLabel3->setPaletteForegroundColor(Qt::black);
+	mainLabel->setPaletteForegroundColor(Qt::black);
 	bgPixmap.resize(0,0);
+	guessButton->setPaletteBackgroundColor("#DCDCDC");
 }
 
-void KHangManView::slotTransparent()
+void KHangManView::slotMilder()
 {
-	if (bgPixmap.isNull())
-		slotNoBkgd();
-	else
-		slotSetPixmap(bgPixmap);
-}
-
-void KHangManView::slotSofter()
-{
-	if (softer)
+	if (Prefs::pictures() == Prefs::EnumPictures::mild) 
 	{
 		px[6].load(locate("data","khangman/pics/hg7c.png"));
 		px[7].load(locate("data","khangman/pics/hg8c.png"));
@@ -474,11 +543,11 @@ void KHangManView::mousePressEvent(QMouseEvent *mouse)
 {
 	if (kvtmlBool && hintBool && (mouse->button() == RightButton))
 	{
-		myPopup = new KPassivePopup(TextLabel3);
+		KPassivePopup *myPopup = new KPassivePopup( Frame11);
 		myPopup->setView(i18n("Hint"), tip );
 		myPopup->setPalette(QToolTip::palette());
 		myPopup->setTimeout(4000); //show for 4 seconds
-		myPopup->show();
+		myPopup->show();	
 	}
         update();//this is nice!
 }
@@ -505,6 +574,12 @@ void KHangManView::readFile()
 	}//end of test
 	word = verbs[wordNumber].originalText();
 	tip = verbs[wordNumber].translatedText(); 
+	kdDebug() << "tip : " << tip << endl;
+	if (tip.isEmpty()) {
+		hintBool = false;
+		Prefs::setHint(false);
+		Prefs::writeConfig();
+		khangman ->changeStatusbar("", 103);}
 }
 
 
