@@ -1,4 +1,3 @@
-// construct_mode.cc
 // Copyright (C)  2003  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -51,18 +50,30 @@ BaseConstructMode::BaseConstructMode( KigPart& d )
 {
   mpt = ObjectFactory::instance()->fixedPointCalcer( Coordinate( 0, 0 ) );
   mpt->calc( d.document() );
+  mcursor = ObjectFactory::instance()->cursorPointCalcer( Coordinate( 0, 0 ) );
+  mcursor->calc( d.document() );
+//  mcursorholder = new ObjectHolder( mcursor );
 }
 
 BaseConstructMode::~BaseConstructMode()
 {
+//  delete mcursorholder;
 }
 
 void BaseConstructMode::leftClickedObject(
   ObjectHolder* o, const QPoint& p, KigWidget& w, bool )
 {
-  bool alreadyselected = std::find( mparents.begin(), mparents.end(), o ) != mparents.end();
+  std::vector<ObjectHolder*>::iterator it = std::find( mparents.begin(), mparents.end(), o );
   std::vector<ObjectCalcer*> nargs = getCalcers( mparents );
-  if ( o && !alreadyselected )
+//
+// mp: duplicationchecked controls whether the arguments list is
+// free of duplications or if a duplication is safe (asking this to
+// the Constructor class through the "isAlreadySelectedOK" method).
+//
+  bool duplicationchecked = 
+        ( it == mparents.end() ) || 
+        isAlreadySelectedOK( nargs, it - mparents.begin() );
+  if ( o && duplicationchecked )
   {
     nargs.push_back( o->calcer() );
     if ( wantArgs( nargs, mdoc.document(), w ) )
@@ -83,6 +94,23 @@ void BaseConstructMode::leftClickedObject(
     // get a new mpt for our further use..
     mpt = ObjectFactory::instance()->sensiblePointCalcer( w.fromScreen( p ), mdoc.document(), w );
     mpt->calc( mdoc.document() );
+    return;
+  }
+
+  nargs = getCalcers( mparents );
+  nargs.push_back( mcursor );
+
+  if ( wantArgs( nargs, mdoc.document(), w ) )
+  {
+    // DON'T add mpt to the document..
+    // the objectholder has been constructed once and for all
+    // when entering construction mode, and delete in the
+    // destructor.
+    ObjectHolder* n = new ObjectHolder( mcursor );
+    selectObject( n, w );
+    mcursor = ObjectFactory::instance()->cursorPointCalcer( w.fromScreen( p ) );
+//    mcursor = ObjectFactory::instance()->sensiblePointCalcer( w.fromScreen( p ), mdoc.document(), w );
+    mcursor->calc( mdoc.document() );
   }
 }
 
@@ -120,15 +148,21 @@ void BaseConstructMode::mouseMoved( const std::vector<ObjectHolder*>& os, const
     ncoord = mdoc.document().coordinateSystem().snapToGrid( ncoord, w );
 
   redefinePoint( mpt.get(), ncoord, mdoc.document(), w );
+  mcursor->move( ncoord, mdoc.document() );
+  mcursor->calc( mdoc.document() );
 
-  bool alreadyselected = false;
   std::vector<ObjectCalcer*> args = getCalcers( mparents );
+  bool duplicationchecked = false;
   if ( ! os.empty() )
   {
-    alreadyselected = std::find( mparents.begin(), mparents.end(), os.front() ) != mparents.end();
-    if ( ! alreadyselected ) args.push_back( os.front()->calcer() );
+    std::vector<ObjectHolder*>::iterator it 
+          = std::find( mparents.begin(), mparents.end(), os.front() );
+    duplicationchecked = 
+          ( it == mparents.end() ) || 
+          isAlreadySelectedOK( args, it - mparents.begin() );
+    if ( duplicationchecked ) args.push_back( os.front()->calcer() );
   }
-  if ( !os.empty() && ! alreadyselected && wantArgs( args, mdoc.document(), w ) )
+  if ( !os.empty() && duplicationchecked && wantArgs( args, mdoc.document(), w ) )
   {
     handlePrelim( args, p, pter, w );
 
@@ -138,6 +172,8 @@ void BaseConstructMode::mouseMoved( const std::vector<ObjectHolder*>& os, const
   {
     std::vector<ObjectCalcer*> args = getCalcers( mparents );
     args.push_back( mpt.get() );
+    std::vector<ObjectCalcer*> argscursor = getCalcers( mparents );
+    argscursor.push_back( mcursor );
     if ( wantArgs( args, mdoc.document(), w ) )
     {
       ObjectDrawer d;
@@ -147,6 +183,15 @@ void BaseConstructMode::mouseMoved( const std::vector<ObjectHolder*>& os, const
 
       w.setCursor( KCursor::handCursor() );
     }
+    else if ( wantArgs( argscursor, mdoc.document(), w ) )
+    {
+      ObjectDrawer d;
+//      d.draw( *mcursor->imp(), pter, true );
+
+      handlePrelim( argscursor, p, pter, w );
+
+      w.setCursor( KCursor::crossCursor() );
+    }
     else
     {
       w.setCursor( KCursor::arrowCursor() );
@@ -274,6 +319,12 @@ void ConstructMode::handlePrelim( const std::vector<ObjectCalcer*>& args, const
   pter.drawTextStd( textloc, o );
 }
 
+int ConstructMode::isAlreadySelectedOK( const std::vector<ObjectCalcer*>& os, 
+                                        const int& pos )
+{
+  return mctor->isAlreadySelectedOK( os, pos );
+}
+
 int ConstructMode::wantArgs( const std::vector<ObjectCalcer*>& os, KigDocument& d, KigWidget& w )
 {
   return mctor->wantArgs( os, d, w );
@@ -334,6 +385,12 @@ void ConstructMode::handleArgs( const std::vector<ObjectCalcer*>& args, KigWidge
   finish();
 }
 
+int TestConstructMode::isAlreadySelectedOK( const std::vector<ObjectCalcer*>&, 
+                                            const int& )
+{
+  return false;
+}
+
 int TestConstructMode::wantArgs( const std::vector<ObjectCalcer*>& os, KigDocument&, KigWidget& )
 {
   return mtype->argsParser().check( os );
@@ -431,3 +488,13 @@ QString TestConstructMode::selectStatement( const std::vector<ObjectCalcer*>& se
   if ( ret.empty() ) return QString::null;
   return i18n( ret.c_str() );
 }
+
+void PointConstructMode::redrawScreen( KigWidget* w )
+{
+  w->redrawScreen( std::vector<ObjectHolder*>() );
+}
+
+void BaseConstructMode::redrawScreen( KigWidget* w )
+{
+  w->redrawScreen( std::vector<ObjectHolder*>() );
+}
