@@ -1,4 +1,3 @@
-// curve_imp.h
 // Copyright (C)  2002  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -36,6 +35,8 @@ public:
    */
   static const ObjectImpType* stype();
 
+  Coordinate attachPoint() const;
+
   // param is between 0 and 1.  Note that 0 and 1 should be the
   // end-points.  E.g. for a Line, getPoint(0) returns a more or less
   // infinite point.  getPoint(0.5) should return the point in the
