@@ -1,4 +1,3 @@
-// object_factory.cc
 // Copyright (C)  2002  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -53,6 +52,15 @@ ObjectTypeCalcer* ObjectFactory::fixedPointCalcer( const Coordinate& c ) const
   return oc;
 }
 
+ObjectTypeCalcer* ObjectFactory::cursorPointCalcer( const Coordinate& c ) const
+{
+  std::vector<ObjectCalcer*> args;
+  args.push_back( new ObjectConstCalcer( new DoubleImp( c.x ) ) );
+  args.push_back( new ObjectConstCalcer( new DoubleImp( c.y ) ) );
+  ObjectTypeCalcer* oc = new ObjectTypeCalcer( CursorPointType::instance(), args );
+  return oc;
+}
+
 const ObjectFactory* ObjectFactory::instance()
 {
   static ObjectFactory f;
@@ -87,6 +95,27 @@ ObjectHolder* ObjectFactory::sensiblePoint(
   return new ObjectHolder( sensiblePointCalcer( c, d, w ) );
 }
 
+ObjectTypeCalcer* ObjectFactory::relativePointCalcer(
+  ObjectCalcer* o, const Coordinate& loc ) const
+{
+  Coordinate reference = 
+      static_cast<const ObjectImp*>( o->imp() )->attachPoint();
+  assert( reference.valid() );
+
+  double x = 0.0;
+  double y = 0.0;
+  if ( loc.valid() )
+  {
+    x = loc.x - reference.x;
+    y = loc.y - reference.y;
+  }
+  std::vector<ObjectCalcer*> parents;
+  parents.push_back( new ObjectConstCalcer( new DoubleImp( x ) ) );
+  parents.push_back( new ObjectConstCalcer( new DoubleImp( y ) ) );
+  parents.push_back( o );
+  return new ObjectTypeCalcer( RelativePointType::instance(), parents );
+}
+
 ObjectTypeCalcer* ObjectFactory::constrainedPointCalcer(
   ObjectCalcer* curve, double param ) const
 {
@@ -174,16 +203,52 @@ ObjectTypeCalcer* ObjectFactory::attachedLabelCalcer(
   parents.reserve( nparents.size() + 3 );
   parents.push_back( new ObjectConstCalcer( new IntImp( needframe ? 1 : 0 ) ) );
 
-  if ( p && p->imp()->inherits( PointImp::stype() ) )
+/*
+ * mp: (changes to add relative-attachment).  Now an object is tested
+ * as follows:
+ * - if attachPoint() returns a valid coordinate, then we use the new method
+ * - if it is a point: 'old-style' treatment (we can change this shortly)
+ * - if it is a curve: 'old-style' treatment (we could use the new approach,
+ *   which can be better/worse depending on personal taste, I think)
+ *
+ * the first condition that matches determines the behaviour.
+ * the new method works similarly to the curve case, but we generate a new
+ * RelativePointType instead of a ConstrainedPointType; this will in turn make use
+ * of the new attachPoint() method for objects.
+ *
+ * changed the preference order 2005/01/21 (now attachPoint has preference over points)
+ *
+ * NOTE: changes in the tests performed should be matched also in
+ * modes/popup.cc (addNameLabel) and in label.cc (TextLabelModeBase::mouseMoved)
+ */
+
+  if ( p && p->imp()->attachPoint().valid() )
+  {
+    ObjectCalcer* o = relativePointCalcer( p, loc );
+    o->calc( doc );
+    parents.push_back( o );
+  }
+  else if ( p && p->imp()->inherits( PointImp::stype() ) )
+  {
     parents.push_back( p );
+  }
   else if ( p && p->imp()->inherits( CurveImp::stype() ) )
   {
-    ObjectCalcer* o = constrainedPointCalcer( p, static_cast<const CurveImp*>( p->imp() )->getParam( loc, doc ) );
+    double param = 0.5;
+    if ( loc.valid() )
+      param = static_cast<const CurveImp*>( p->imp() )->getParam( loc, doc );
+
+    ObjectCalcer* o = constrainedPointCalcer( p, param );
     o->calc( doc );
     parents.push_back( o );
   }
   else
-    parents.push_back( new ObjectConstCalcer( new PointImp( loc ) ) );
+  {
+    if ( loc.valid() )
+      parents.push_back( new ObjectConstCalcer( new PointImp( loc ) ) );
+    else
+      parents.push_back( new ObjectConstCalcer( new PointImp( Coordinate( 0, 0 ) ) ) );
+  }
 
   parents.push_back( new ObjectConstCalcer( new StringImp( s ) ) );
   std::copy( nparents.begin(), nparents.end(), std::back_inserter( parents ) );
