@@ -1,6 +1,7 @@
 /**
  This file is part of Kiten, a KDE Japanese Reference Tool...
  Copyright (C) 2001  Jason Katz-Brown <jason@katzbrown.com>
+	       (C) 2005 Paul Temple <paul.temple@gmx.net>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,6 +22,7 @@
 #include <kaction.h>
 #include <kapplication.h>
 #include <kconfig.h>
+#include <kconfigdialog.h>
 #include <kdebug.h>
 #include <kdeversion.h>
 #include <kedittoolbar.h>
@@ -38,6 +40,7 @@
 
 #include "kiten.h"
 #include "learn.h"
+#include "kitenconfig.h"
 #include "optiondialog.h"
 
 #include <cassert>
@@ -48,6 +51,8 @@ TopLevel::TopLevel(QWidget *parent, const char *name) : KMainWindow(parent, name
 	    setStandardToolBarMenuEnabled(true);
 #endif
 
+	config = Config::self();
+	config->readConfig();
 	Accel = new KGlobalAccel(this);
 	(void) Accel->insert("Lookup Kanji (Kanjidic)", i18n("Lookup Kanji (Kanjidic)"), i18n("Gives detailed information about Kanji currently on clipboard."), CTRL + ALT + Key_K, CTRL + ALT + Key_K, this, SLOT(kanjiSearchAccel()));
 	(void) Accel->insert("Lookup English/Japanese word", i18n("Lookup English/Japanese Word"), i18n("Looks up current text on clipboard in the same way as if you used Kiten's regular search."), CTRL + ALT + Key_S, CTRL + ALT + Key_S, this, SLOT(searchAccel()));
@@ -66,9 +71,9 @@ TopLevel::TopLevel(QWidget *parent, const char *name) : KMainWindow(parent, name
 	(void) new KAction(i18n("Ra&dical Search..."), "gear", CTRL+Key_R, this, SLOT(radicalSearch()), actionCollection(), "search_radical");
 	Edit = new EditAction(i18n("Search Edit"), 0, this, SLOT(search()), actionCollection(), "search_edit");
 	(void) new KAction(i18n("&Clear Search Bar"), BarIcon("locationbar_erase", 16), CTRL+Key_N, Edit, SLOT(clear()), actionCollection(), "clear_search");
-	(void) new KAction(i18n("&Search"), "key_enter", 0, this, SLOT(search()), actionCollection(), "search");
+	(void) new KAction(i18n("S&earch"), "key_enter", 0, this, SLOT(search()), actionCollection(), "search");
 	(void) new KAction(i18n("Search with &Beginning of Word"), 0, this, SLOT(searchBeginning()), actionCollection(), "search_beginning");
-	(void) new KAction(i18n("&Search Anywhere"), 0, this, SLOT(searchAnywhere()), actionCollection(), "search_anywhere");
+	(void) new KAction(i18n("Search &Anywhere"), 0, this, SLOT(searchAnywhere()), actionCollection(), "search_anywhere");
 	(void) new KAction(i18n("Stro&kes"), "paintbrush", CTRL+Key_S, this, SLOT(strokeSearch()), actionCollection(), "search_stroke");
 	(void) new KAction(i18n("&Grade"), "leftjust", CTRL+Key_G, this, SLOT(gradeSearch()), actionCollection(), "search_grade");
 	kanjiCB = new KToggleAction(i18n("&Kanjidic"), "kanjidic", CTRL+Key_K, this, SLOT(kanjiDictChange()), actionCollection(), "kanji_toggle");
@@ -94,16 +99,14 @@ TopLevel::TopLevel(QWidget *parent, const char *name) : KMainWindow(parent, name
 	StatusBar = statusBar();
 	optionDialog = 0;
 
-	KConfig *config = kapp->config();
-	config->setGroup("app");
-	bool com = config->readBoolEntry("com", false);
-	comCB->setChecked(com);
-	kanjiCB->setChecked(config->readBoolEntry("kanji", false));
-	autoSearchToggle->setChecked(config->readBoolEntry("autosearch", false));
-	deinfCB->setChecked(config->readBoolEntry("deinf", true));
+	comCB->setChecked(config->com());
+	kanjiCB->setChecked(config->kanji());
+	autoSearchToggle->setChecked(config->autosearch());
+	deinfCB->setChecked(config->deinf());
 
-	slotUpdateConfiguration();
-	if (autoCreateLearn)
+	updateConfiguration();
+
+	if (config->startLearn())
 		createLearn();
 
 	resize(600, 400);
@@ -128,9 +131,9 @@ void TopLevel::finishInit()
 	if (!kapp->config()->hasGroup("app"))
 	{
 		if (kanjiCB->isChecked())
-			Edit->setText(QTextCodec::codecForName("eucJP")->toUnicode(QCString("")));
+		  	Edit->setText(QString::fromUtf8("辞"));
 		else
-			Edit->setText(QTextCodec::codecForName("eucJP")->toUnicode(QCString("")));
+		  	Edit->setText(QString::fromUtf8("辞書"));
 
 		search();
 	}
@@ -152,17 +155,11 @@ bool TopLevel::queryClose()
 		learnList.remove(old);
 	}
 
-	KConfig *config = kapp->config();
-	config->setGroup("app");
-	config->writeEntry("com", comCB->isChecked());
-	config->writeEntry("kanji", kanjiCB->isChecked());
-	config->writeEntry("autosearch", autoSearchToggle->isChecked());
-	config->writeEntry("deinf", deinfCB->isChecked());
-
-	config->setGroup("kanjidic");
-	config->writeEntry("__useGlobal", kanjidicUseGlobal);
-	config->setGroup("edict");
-	config->writeEntry("__useGlobal", edictUseGlobal);
+	config->setCom(comCB->isChecked());
+	config->setKanji(kanjiCB->isChecked());
+	config->setAutosearch(autoSearchToggle->isChecked());
+	config->setDeinf(deinfCB->isChecked());
+	config->writeConfig();
 
 	saveMainWindowSettings(KGlobal::config(), "TopLevelWindow");
 	return true;
@@ -178,7 +175,7 @@ void TopLevel::addToList()
 	emit add(toAddKanji);
 }
 
-void TopLevel::doSearch(QString text, QRegExp regexp)
+void TopLevel::doSearch(const QString &text, QRegExp regexp)
 {
 	if (text.isEmpty())
 	{
@@ -191,11 +188,11 @@ void TopLevel::doSearch(QString text, QRegExp regexp)
 	Dict::SearchResult results;
 	if (kanjiCB->isChecked())
 	{
-		results = _Index.searchKanji(regexp, text, comCB->isChecked());
+		results = _Asyndeta.retrieveIndex()->searchKanji(regexp, text, comCB->isChecked());
 	}
 	else
 	{
-		results = _Index.search(regexp, text, comCB->isChecked());
+		results = _Asyndeta.retrieveIndex()->search(regexp, text, comCB->isChecked());
 
 		// do again... bad because sometimes reading is kanji
 		if ((readingSearch || beginningReadingSearch) && (results.count < 1))
@@ -207,7 +204,7 @@ void TopLevel::doSearch(QString text, QRegExp regexp)
 			else if (readingSearch)
 				regexp = kanjiSearchItems();
 
-			results = _Index.search(regexp, text, comCB->isChecked());
+			results = _Asyndeta.retrieveIndex()->search(regexp, text, comCB->isChecked());
 		}
 	}
 
@@ -216,7 +213,7 @@ void TopLevel::doSearch(QString text, QRegExp regexp)
 	readingSearch = false;
 }
 
-void TopLevel::doSearchInResults(QString text, QRegExp regexp)
+void TopLevel::doSearchInResults(const QString &text, QRegExp regexp)
 {
 	if (text.isEmpty())
 	{
@@ -225,7 +222,7 @@ void TopLevel::doSearchInResults(QString text, QRegExp regexp)
 	}
 
 	StatusBar->message(i18n("Searching..."));
-	Dict::SearchResult results = _Index.searchPrevious(regexp, text, *currentResult, comCB->isChecked());
+	Dict::SearchResult results = _Asyndeta.retrieveIndex()->searchPrevious(regexp, text, *currentResult, comCB->isChecked());
 	addHistory(results);
 	handleSearchResult(results);
 	readingSearch = false;
@@ -265,11 +262,11 @@ void TopLevel::handleSearchResult(Dict::SearchResult results)
 
 			_ResultView->addHeader(i18n("%1 in compounds").arg(kanji));
 
-			Dict::SearchResult compounds = _Index.search(QRegExp(kanji), kanji, true);
+			Dict::SearchResult compounds = _Asyndeta.retrieveIndex()->search(QRegExp(kanji), kanji, true);
 			bool common = true;
 			if (compounds.count <= 0)
 			{
-				compounds = _Index.search(QRegExp(kanji), kanji, false);
+				compounds = _Asyndeta.retrieveIndex()->search(QRegExp(kanji), kanji, false);
 				_ResultView->addHeader(i18n("(No common compounds)"), 4);
 				common = false;
 			}
@@ -401,7 +398,7 @@ void TopLevel::search(bool inResults)
 						continue;
 
 					//kdDebug() << "currently on deinflection " << *it << endl;
-					Dict::SearchResult results = _Index.search(QRegExp(QString("^") + (*it) + "\\W"), *it, common);
+					Dict::SearchResult results = _Asyndeta.retrieveIndex()->search(QRegExp(QString("^") + (*it) + "\\W"), *it, common);
 
 					if (results.count < 1) // stop if it isn't in the dictionary
 						continue;
@@ -592,87 +589,36 @@ void TopLevel::setResults(unsigned int results, unsigned int fullNum)
 	setCaption(str);
 }
 
-void TopLevel::slotUpdateConfiguration()
+void TopLevel::slotConfigurationChanged()
 {
-	KConfig *config = kapp->config();
-	KStandardDirs *dirs = KGlobal::dirs();
-	QString globaledict = dirs->findResource("appdata", "edict");
-	QString globalkanjidic = dirs->findResource("appdata", "kanjidic");
-	personalDict = KGlobal::dirs()->saveLocation("appdata", "dictionaries/", true).append("personal");
-
-	config->setGroup("edict");
-
-	edictUseGlobal = config->readBoolEntry("__useGlobal", true);
-
-	QStringList DictNameList = config->readListEntry("__NAMES");
-	QStringList DictList;
-
-	QStringList::Iterator it;
-
-	for (it = DictNameList.begin(); it != DictNameList.end(); ++it)
-		DictList.append(config->readEntry(*it));
-
-	if (QFile::exists(personalDict))
-	{
-		DictList.prepend(personalDict);
-		DictNameList.prepend(i18n("Personal"));
-	}
-
-	if (!globaledict.isNull() && edictUseGlobal)
-	{
-		DictList.prepend(globaledict);
-		DictNameList.prepend("Edict");
-	}
-
-	_Index.setDictList(DictList, DictNameList);
-
-	config->setGroup("kanjidic");
-
-	kanjidicUseGlobal = config->readBoolEntry("__useGlobal", true);
-
-	DictList.clear();
-	DictNameList = config->readListEntry("__NAMES");
-
-	for (it = DictNameList.begin(); it != DictNameList.end(); ++it)
-		DictList.append(config->readEntry(*it));
-
-	if (!globalkanjidic.isNull() && kanjidicUseGlobal)
-	{
-		DictList.prepend(globalkanjidic);
-		DictNameList.prepend("Kanjidic");
-	}
-
-	_Index.setKanjiDictList(DictList, DictNameList);
-
-	config->setGroup("Learn");
-	autoCreateLearn = config->readBoolEntry("startLearn", false);
-
-	config->setGroup("Searching Options");
-	wholeWord = config->readBoolEntry("wholeWord", true);
-	caseSensitive = config->readBoolEntry("caseSensitive", false);
+	updateConfiguration();
+}
 
+void TopLevel::updateConfiguration()
+{
+	_Asyndeta.readKitenConfiguration();
 	_ResultView->updateFont();
 }
 
 void TopLevel::slotConfigure()
 {
-	if (optionDialog == 0)
-	{
-		optionDialog = new ConfigureDialog(Accel, 0);
-		if (optionDialog == 0)
-			return;
-		connect(optionDialog, SIGNAL(hidden()),this,SLOT(slotConfigureHide()));
-		connect(optionDialog, SIGNAL(valueChanged()), this, SLOT(slotUpdateConfiguration()));
-		connect(optionDialog, SIGNAL(valueChanged()), this, SIGNAL(quizConfChanged()));
-	}
-
+	if (ConfigureDialog::showDialog("settings"))
+		return;
+	
+	//ConfigureDialog didn't find an instance of this dialog, so lets create it :
+	optionDialog = new ConfigureDialog(Accel, this, "settings");
+	connect(optionDialog, SIGNAL(hidden()),this,SLOT(slotConfigureHide()));
+	connect(optionDialog, SIGNAL(settingsChanged()), this, SLOT(slotConfigurationChanged()));
+	connect(optionDialog, SIGNAL(valueChanged()), this, SIGNAL(quizConfChanged()));
 	optionDialog->show();
+
+	return;
 }
 
 void TopLevel::slotLearnConfigure()
 {
 	slotConfigure();
-	optionDialog->showPage(4);
+	optionDialog->showPage(2);
 }
 
 void TopLevel::slotConfigureHide()
@@ -691,7 +637,7 @@ void TopLevel::slotConfigureDestroy()
 
 void TopLevel::createLearn()
 {
-	Learn *_Learn = new Learn(&_Index, 0);
+	Learn *_Learn = new Learn(_Asyndeta.retrieveIndex(), 0);
 
 	connect(_Learn, SIGNAL(destroyed(Learn *)), this, SLOT(learnDestroyed(Learn *)));
 	connect(_Learn, SIGNAL(linkClicked(const QString &)), this, SLOT(ressearch(const QString &)));
@@ -711,7 +657,7 @@ void TopLevel::learnDestroyed(Learn *learn)
 
 void TopLevel::createEEdit()
 {
-	eEdit *_eEdit = new eEdit(personalDict, this);
+	eEdit *_eEdit = new eEdit(_Asyndeta.personalDictionaryLocation(), this);
 	_eEdit->show();
 }
 
@@ -735,7 +681,7 @@ QRegExp TopLevel::readingSearchItems(bool kanji)
 
 	regexp = regexp.arg(text);
 
-	return QRegExp(regexp, caseSensitive);
+	return QRegExp(regexp, Config::caseSensitive());
 }
 
 QRegExp TopLevel::kanjiSearchItems(bool beginning)
@@ -753,7 +699,7 @@ QRegExp TopLevel::kanjiSearchItems(bool beginning)
 
 	regexp = regexp.arg(text);
 
-	return QRegExp(regexp, caseSensitive);
+	return QRegExp(regexp, Config::caseSensitive());
 }
 
 QRegExp TopLevel::searchItems()
@@ -764,14 +710,14 @@ QRegExp TopLevel::searchItems()
 		return QRegExp(); //empty
 
 	unsigned int contains = text.contains(QRegExp("[A-Za-z0-9_:]"));
-	if (wholeWord && contains == text.length())
+	if (Config::wholeWord() && contains == text.length())
 		regexp = "\\W%1\\W";
 	else
 		regexp = "%1";
 
 	regexp = regexp.arg(text);
 
-	return QRegExp(regexp, caseSensitive);
+	return QRegExp(regexp, Config::caseSensitive());
 }
 
 void TopLevel::toggleCom()
@@ -852,7 +798,7 @@ void TopLevel::radSearch(const QStringList &_list, unsigned int strokes, unsigne
 	for (it = list.begin(); it != list.end(); ++it)
 	{
 
-		Dict::SearchResult results = _Index.searchKanji(QRegExp(strokes? (QString("S%1 ").arg(strokesString)) : (QString("^") + (*it)) ), (*it), comCB->isChecked());
+		Dict::SearchResult results = _Asyndeta.retrieveIndex()->searchKanji(QRegExp(strokes? (QString("S%1 ").arg(strokesString)) : (QString("^") + (*it)) ), (*it), comCB->isChecked());
 		hist.outOf += results.outOf;
 
 		if (results.count < 1)
