@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2004 Anne-Marie Mahfouf <annma@kde.org>
+ * Copyright (C) 2001-2005 Anne-Marie Mahfouf <annma@kde.org>
  *
     This program is free software; you can redistribute it and/or
     modify it under the terms of version 2 of the GNU General Public
@@ -32,6 +32,7 @@
 #include <kconfigdialog.h>
 #include <ktoolbarbutton.h>
 #include <knuminput.h>
+#include <kiconloader.h>
 //Project headers
 #include "klnewstuff.h"
 #include "klettres.h"
@@ -57,7 +58,7 @@ KLettres::KLettres()
 	soundFactory = new SoundFactory(this, "sounds");
 	//Read config, must come after SoundFactory, otherwise we don't have all languages
 	loadSettings();
-	// activate language
+	// activate language selectedLanguage is default or saved current language
 	soundFactory->change(selectedLanguage);
 	//Set up StatusBar
 	KStatusBar *st=statusBar();
@@ -90,6 +91,9 @@ KLettres::KLettres()
 	//toolbar for special characters
 	secondToolbar = toolBar("secondToolbar");
 	
+	changeLookAction = new KAction(i18n("Switch to Kid Look"), "klettres_kids.png", this, SLOT(switchLook()), actionCollection());
+	changeLookAction->plug(tb);
+	
 	//from the Read config, growup is set as default if no style
 	if (Prefs::style() == Prefs::EnumStyle::grownup)
 		slotGrownup();
@@ -122,7 +126,7 @@ void KLettres::setupActions()
 	new KAction( i18n("Get New Language..."), "knewstuff", 0, this, SLOT( downloadNewStuff() ), actionCollection(), "downloadnewstuff" );
 	KStdAction::quit(kapp, SLOT(quit()), actionCollection());
 
-	m_action = new KToggleAction(i18n("Show &Menubar"),CTRL+Key_M, this, SLOT(slotMenubar()), actionCollection(), "menubar");
+	m_action = new KToggleAction(i18n("Show &Menubar"),"showmenu", CTRL+Key_M, this, SLOT(slotMenubar()), actionCollection(), "showmenubar");
 	m_action->setCheckedState(i18n("Hide &Menubar"));
 	m_action->setChecked(true);
 
@@ -141,6 +145,7 @@ void KLettres::setupActions()
 void KLettres::registerLanguage(const QString &language, const QString &menuItem)
 {
 	m_languages.append(language);
+	kdDebug() << "m_languages :" << m_languages << endl;
 	//this is for translation of the languages
 	KConfig entry(locate("locale", "all_languages"));
 	entry.setGroup(language);
@@ -168,6 +173,8 @@ void KLettres::changeLanguage(int newLanguage)
 
 bool KLettres::loadLayout(QDomDocument &layoutDocument)
 {
+	kdDebug() << "m_languages :" << m_languages << endl;
+	kdDebug() << "language code :" << m_languages[Prefs::languageNumber()] << endl;
 	//QFile layoutFile(QFile::encodeName(locate("data", "klettres/data/sounds.xml")));
 	QFile layoutFile(locate("data", "klettres/data/sounds.xml"));
 	//if xml file is not found, program exits
@@ -225,6 +232,12 @@ void KLettres::optionsPreferences()
 	dialog->show();
 }
 
+void KLettres::switchLook()
+{
+	if (grownBool) slotGrownup();
+	else slotKid();
+}
+
 void KLettres::slotGrownup()
 {
 	QPalette pal;
@@ -237,9 +250,10 @@ void KLettres::slotGrownup()
 	langLabel->setFont(f_lab);
 	m_action->setChecked(true);
 	slotMenubar();
-	if (grownBool) tb->removeItem(ID_GROWNB);
-	tb->insertButton ("kids.png", ID_KIDB, SIGNAL( clicked() ), this, SLOT( slotKid()), true, i18n("Switch to the kid look"), 9 );
+	changeLookAction->setText(i18n("Switch to Kid Look"));
+	changeLookAction->setIcon("klettres_kids.png");
 	kidBool=true;
+	grownBool=false;
 	m_view->slotGrownup();
 	secondToolbar->setIconSize(22);
 	setMinimumSize( QSize( 640, 538 ) );
@@ -259,9 +273,10 @@ void KLettres::slotKid()
 	langLabel->setFont(f_lab);
 	m_action->setChecked(false);
 	slotMenubar();
-	if (kidBool) tb->removeItem(ID_KIDB);
-	tb->insertButton ("grownup.png", ID_GROWNB, SIGNAL( clicked() ), this, SLOT( slotGrownup()), true, i18n("Switch to the grown-up look"),10 );
+	changeLookAction->setText(i18n("Switch to Grown-Up Look"));
+	changeLookAction->setIcon("klettres_grownup.png");
 	grownBool=true;
+	kidBool=false;
 	m_view->slotKid();
 	secondToolbar->setIconSize(32);
 	setMinimumSize( QSize( 640, 480 ) );
@@ -275,14 +290,13 @@ void KLettres::slotMenubar()
 		case false:
 			m_action->setChecked(false);
 			menuBar()->hide();
-			if (menuBool) tb->removeItem(ID_MENUBARB);//check if it is already here. if yes, remove it
-			tb->insertButton ("menubar.png", ID_MENUBARB, SIGNAL( clicked() ), this, SLOT( slotShowM()), true, i18n("Show the MenuBar"), 8 );
+			m_action->plug(tb);
 			menuBool=true;
 			break;
 		case true:
 			m_action->setChecked(true);
 			menuBar()->show();
-			if (menuBool) tb->removeItem(ID_MENUBARB);
+			if (menuBool) m_action->unplug(tb);
 			menuBool=false;//false if no menubar button
 			break;
 		}
@@ -417,6 +431,8 @@ void KLettres::slotTimer()
 	KConfigDialog *dialog = new KConfigDialog(this, "timer", Prefs::self());
 	timerdlg *m_timer = new timerdlg();
 	dialog->addPage(m_timer, i18n("Timer"), "clock");
+	m_timer->kidPixLabel -> setPixmap(KGlobal::iconLoader()->loadIcon("klettres_kids", KIcon::NoGroup));
+	m_timer->grownPixLabel -> setPixmap(KGlobal::iconLoader()->loadIcon("klettres_grownup", KIcon::NoGroup));
 	m_timer->kcfg_KidTimer->setRange(0, 20, 2, true);
 	m_timer->kcfg_GrownTimer->setRange(0, 20, 2, true);
 	connect(dialog, SIGNAL(settingsChanged()), this, SLOT(loadSettings()));
