@@ -1,4 +1,20 @@
-#include <klocale.h>
+/***************************************************************************
+                          answer.cpp  -  description
+                             -------------------
+    begin                : Thu Mar 28 2002
+    copyright            : (C) 2002 by Primoz Anzur 
+    email                : zerokode@gmx.net
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
+ #include <klocale.h>
 
 #include "answer.h"
 #include <kdebug.h>
@@ -7,24 +23,24 @@
 #include <kstdguiitem.h>
 
 /*
- *  Constructs a Answer which is a child of 'parent', with the
+ *  Constructs a Answer which is a child of 'parent', with the 
  *  name 'name' and widget flags set to 'f'.
  *
  *  The dialog will by default be modeless, unless you set 'modal' to
  *  TRUE to construct a modal dialog.
  */
-Answer::Answer( QWidget* parent,  const char* name, bool modal, WFlags fl )
+Answer::Answer( QWidget* parent,  const char* name, bool modal, WFlags  )
     : QDialog( parent, name, modal, true)
 {
     if ( !name )
 	setName( "Answer" );
-    resize( 256, 256 );
+    resize( 256, 256 ); 
     setMinimumSize( QSize( 256, 256 ) );
     setMaximumSize( QSize( 256, 256 ) );
     setCaption( tr2i18n( "Answer" ) );
-    AnswerLayout = new QGridLayout( this, 1, 1, 11, 6, "AnswerLayout");
+    AnswerLayout = new QGridLayout( this, 1, 1, 11, 6, "AnswerLayout"); 
 
-    Layout2 = new QHBoxLayout( 0, 0, 6, "Layout2");
+    Layout2 = new QHBoxLayout( 0, 0, 6, "Layout2"); 
 
     btnReplay = new QPushButton( this, "btnReplay" );
     btnReplay->setText( tr2i18n( "&Play Again" ) );
@@ -68,12 +84,12 @@ void Answer::replayGame()
 }
 
 void Answer::doAnswer(bool result){
-	kdDebug() << result << endl;
+	kdDebug() << result << endl;	
 
 	if(result){
 		btnReplay->setEnabled(true);
 		btnQuit->setGuiItem(KStdGuiItem::quit());
-		setCaption(i18n("Congratulations!"));
+		setCaption(i18n("Congratulations!"));                
 		setBackgroundPixmap(QPixmap(locate("data","kmessedwords/dudeyes.png")));
 		getAnswer=false;
 	} else {
