@@ -17,6 +17,7 @@
 #include "indiproperty.h"
 #include "indigroup.h"
 #include "indidevice.h"
+#include "indi/indicom.h"
 #include "kstars.h"
 #include "kstarsdatetime.h"
 
@@ -136,50 +137,51 @@ bool DeviceManager::indiConnect(QString inHost, QString inPort)
 void DeviceManager::dataReceived()
 {
 	char ibuf[32];	/* not so much user input lags */
-	char msg[1024];
+	char errmsg[ERRMSG_SIZE];
 	int i, nr;
 
 	/* read INDI command */
-	nr = read (serverFD, ibuf, sizeof(ibuf));
+	nr = read (serverFD, ibuf, sizeof(ibuf)-1);
 	if (nr <= 0)
 	{
 	    if (nr < 0)
-		sprintf (msg, "INDI: input error.");
+		strcpy (errmsg, "INDI: input error.");
 	    else
-		sprintf (msg, "INDI: agent closed connection.");
+		strcpy (errmsg, "INDI: agent closed connection.");
 
 
             tcflush(serverFD, TCIFLUSH);
 	    sNotifier->disconnect();
 	    close(serverFD);
 	    parent->removeDeviceMgr(mgrID);
-	    KMessageBox::error(0, QString(msg));
+	    KMessageBox::error(0, QString::fromLatin1(errmsg));
 
             return;
 	}
 
+        ibuf[ sizeof( ibuf )-1 ] = '\0';
+
 	/* process each char */
 	for (i = 0; i < nr; i++)
 	{
   	  if (!XMLParser)
 	     	return;
 
-	    XMLEle *root = readXMLEle (XMLParser, (int)ibuf[i], msg);
+	    XMLEle *root = readXMLEle (XMLParser, (int)ibuf[i], errmsg);
 	    if (root)
 	    {
                 //prXMLEle (stdout, root, 0);
-		if (dispatchCommand(root, msg) < 0)
+		if (dispatchCommand(root, errmsg) < 0)
 		{
-		    //kdDebug() << msg << endl;
-		    fprintf(stderr, msg);
+		    fprintf(stderr, "%s", errmsg);
 		    prXMLEle (stdout, root, 0);
 		}
 
 		delXMLEle (root);
 	    }
-	    else if (msg[0])
+	    else if (*errmsg)
 	    {
-		kdDebug() << msg << endl;
+		kdDebug() << errmsg << endl;
 	    }
 	}
 }
@@ -271,7 +273,7 @@ int DeviceManager::removeDevice(QString devName, char errmsg[])
 	 }
     }
 
-   sprintf(errmsg, "Device %s not found" , devName.ascii());
+   snprintf(errmsg, ERRMSG_SIZE, "Device %.32s not found" , devName.ascii());
    return -1;
 }
 
@@ -284,7 +286,7 @@ INDI_D * DeviceManager::findDev (QString devName, char errmsg[])
 		return (indi_dev.at(i));
 	}
 
-	sprintf (errmsg, "INDI: no such device %s", devName.ascii());
+	snprintf (errmsg, ERRMSG_SIZE, "INDI: no such device %.32s", devName.ascii());
 	kdDebug() << errmsg;
 
 	return NULL;
@@ -342,7 +344,7 @@ INDI_D * DeviceManager::findDev (XMLEle *root, int create, char errmsg[])
 		return (addDevice (root, errmsg));
 
 
-	sprintf (errmsg, "INDI: <%s> no such device %s", tagXMLEle(root), dn);
+	snprintf (errmsg, ERRMSG_SIZE, "INDI: <%.32s> no such device %.32s", tagXMLEle(root), dn);
 	return NULL;
 }
 
