@@ -17,7 +17,7 @@
  #include "indimenu.h"
  #include "indistd.h"
  #include "indi/indicom.h"
- #include "kstarsoptions.h"
+ #include "Options.h"
  #include "kstars.h"
  #include "timedialog.h"
  
@@ -29,6 +29,7 @@
  #include <kpushbutton.h>
  #include <knuminput.h> 
  #include <kdebug.h>
+ #include <kmessagebox.h>
  
  #include <qbuttongroup.h> 
  #include <qcheckbox.h>
@@ -106,6 +107,7 @@ INDI_E * INDI_P::findElement(QString elementName)
 void INDI_P::drawLt(PState lstate)
 {
 
+  
         /* set state light */
 	switch (lstate)
 	{
@@ -115,6 +117,8 @@ void INDI_P::drawLt(PState lstate)
 
 	  case PS_OK:
 	  light->setColor(Qt::green);
+	  emit okState();
+	  disconnect( this, SIGNAL(okState()), 0, 0 );
 	  break;
 
 	  case PS_BUSY:
@@ -129,6 +133,7 @@ void INDI_P::drawLt(PState lstate)
 	  break;
 
 	}
+	
 }
 
 void INDI_P::newText()
@@ -161,8 +166,15 @@ void INDI_P::newText()
 	}
 	
 	if (guitype == PG_NUMERIC)
+	{
            f_scansexa(lp->text.ascii(), &(lp->targetValue));
-      }
+	   if ((lp->targetValue > lp->max || lp->targetValue < lp->min))
+	   {
+	     KMessageBox::error(0, i18n("Invalid range. Valid values range from %1 to %2").arg(lp->min).arg(lp->max));
+	     return;
+	   }
+        }
+     }
   }
 
   state = PS_BUSY;
@@ -188,6 +200,14 @@ void INDI_P::convertSwitch(int id)
  if (assosiatedPopup == NULL)
   return;
 
+  //kdDebug() << "Name: " << name << " ID: " << id << endl;
+ /* Special case is EXPOSE_DURATION, not a switch */
+ if (stdID == EXPOSE_DURATION && assosiatedPopup->text(id) == label)
+ {
+   newText();
+   return;
+ }
+   
  lp = findElement(assosiatedPopup->text(id));
  
  if (!lp)
@@ -232,7 +252,7 @@ void INDI_P::newSwitch(int id)
    case PG_BUTTONS:
       for (unsigned int i=0; i < el.count(); i++)
       {
-          if (i == id) continue;
+          if (i == (unsigned int) id) continue;
 	  
      	  el.at(i)->push_w->setDown(false);
        	  buttonFont = el.at(i)->push_w->font();
@@ -253,6 +273,9 @@ void INDI_P::newSwitch(int id)
    	lp->state = lp->state == PS_ON ? PS_OFF : PS_ON;
    	lp->check_w->setChecked(lp->state == PS_ON);
    break;
+   
+   default:
+    break;
 
   }
 
@@ -278,7 +301,8 @@ void INDI_P::addGUI (XMLEle *root)
 	/* add to GUI group */
 	light = new KLed (pg->propertyContainer);
 	light->setMaximumSize(16,16);
-	light->setLook( KLed::Sunken );
+	light->setLook(KLed::Sunken);
+	//light->setShape(KLed::Rectangular);
 	drawLt(state);
 	
 	/* #1 First widegt is the LED status indicator */
@@ -292,7 +316,7 @@ void INDI_P::addGUI (XMLEle *root)
 	else
 	    label = valuXMLAtt(prompt);
 	
-	// use property name is label is empty
+	// use property name if label is empty
 	if (label.isEmpty())
 	{
 	   label = name;
@@ -324,6 +348,7 @@ int INDI_P::buildTextGUI(XMLEle *root, char errmsg[])
 	XMLEle *text;
 	XMLAtt *ap;
         QString textName, textLabel ;
+	errmsg=errmsg;
 	
         for (text = nextXMLEle (root, 1); text != NULL; text = nextXMLEle (root, 0))
 	{
@@ -369,7 +394,7 @@ int INDI_P::buildTextGUI(XMLEle *root, char errmsg[])
 	 // INDI STD, but we use our own controls
 	 if (name == "TIME")
 	 {
-	        setupSetButton("Set Time...");
+	        setupSetButton("Time");
 	     	QObject::connect(set_w, SIGNAL(clicked()), indistd, SLOT(newTime()));
 	 }
 	 else
@@ -385,11 +410,12 @@ int INDI_P::buildTextGUI(XMLEle *root, char errmsg[])
 int INDI_P::buildNumberGUI  (XMLEle *root, char errmsg[])
 {
   	char format[32];
-	double min, max, step;
+	double min=0, max=0, step=0;
 	XMLEle *number;
 	XMLAtt *ap;
 	INDI_E *lp;
 	QString numberName, numberLabel;
+	errmsg=errmsg;
 	
 	for (number = nextXMLEle (root, 1); number != NULL; number = nextXMLEle (root, 0))
 	{
@@ -506,7 +532,7 @@ int INDI_P::buildMenuGUI(XMLEle *root, char errmsg[])
 
 	    if (pg->dp->crackSwitchState (pcdataXMLEle(sep), &(lp->state)) < 0)
 	    {
-		sprintf (errmsg, "INDI: <%s> unknown state %s for %s %s %s",
+		snprintf (errmsg, ERRMSG_SIZE, "INDI: <%.64s> unknown state %.64s for %.64s %.64s %.64s",
 			    tagXMLEle(root), valuXMLAtt(ap), name.ascii(), lp->name.ascii(), name.ascii());
 		return (-1);
 	    }
@@ -517,7 +543,7 @@ int INDI_P::buildMenuGUI(XMLEle *root, char errmsg[])
 	    {
 		if (onItem != -1)
 		{
-		    sprintf (errmsg,"INDI: <%s> %s %s has multiple On switches",
+		    snprintf (errmsg, ERRMSG_SIZE, "INDI: <%.64s> %.64s %.64s has multiple On switches",
 					tagXMLEle(root), name.ascii(), lp->name.ascii());
 		    return (-1);
 		}
@@ -587,7 +613,7 @@ int INDI_P::buildSwitchesGUI(XMLEle *root, char errmsg[])
 
 	    if (pg->dp->crackSwitchState (pcdataXMLEle(sep), &(lp->state)) < 0)
 	    {
-		sprintf (errmsg, "INDI: <%s> unknown state %s for %s %s %s",
+		snprintf (errmsg, ERRMSG_SIZE, "INDI: <%.64s> unknown state %.64s for %.64s %.64s %.64s",
 			    tagXMLEle(root), valuXMLAtt(ap), name.ascii(), name.ascii(), lp->name.ascii());
 		return (-1);
 	    }
@@ -685,7 +711,7 @@ int INDI_P::buildLightsGUI(XMLEle *root, char errmsg[])
 
 	   if (pg->dp->crackLightState (pcdataXMLEle(lep), &lp->state) < 0)
 	    {
-		sprintf (errmsg, "INDI: <%s> unknown state %s for %s %s %s",
+		snprintf (errmsg, ERRMSG_SIZE, "INDI: <%.64s> unknown state %.64s for %.64s %.64s %.64s",
 			    tagXMLEle(root), valuXMLAtt(ap), pg->dp->name.ascii(), name.ascii(), sname.ascii());
 		return (-1);
 	   }
@@ -700,3 +726,22 @@ int INDI_P::buildLightsGUI(XMLEle *root, char errmsg[])
 
 	return (0);
 }
+
+void INDI_P::activateSwitch(QString name)
+{
+  int iCounter = 0;
+  INDI_E *element;
+  
+  for (element = el.first(); element != NULL; element = el.next())
+  {
+     if (element->name == name && element->push_w)
+       newSwitch(iCounter);
+     
+     iCounter++;
+  }
+  
+}
+
+
+
+#include "indiproperty.moc"
