@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: UsageManager.h,v 1.3 2003/07/17 12:48:21 binner Exp $
+    $Id: UsageManager.h,v 1.4 2004/11/06 00:09:28 hedlund Exp $
 
                           manage usage labels
 
@@ -96,7 +96,7 @@ struct UsageRelation
 {
  public:
 
-  UsageRelation (QString id, QString shorty, QString longy)
+  UsageRelation (const QString & id, const QString & shorty, const QString & longy)
     :ident(id), shortId(shorty), longId(longy) {}
 
   QString identStr() const { return ident; }
