@@ -1,17 +1,15 @@
 /***************************************************************************
 
-    $Id: QueryOptionsDlg.cpp,v 1.11 2003/07/17 12:48:22 binner Exp $
-
                      query options dialog class
 
     -----------------------------------------------------------------------
 
     begin                : Thu Mar 11 20:50:53 MET 1999
-                                           
+
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
-                         
-    email                : kvoctrain@ewald-arnold.de                                    
+
+    email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
 
@@ -22,22 +20,19 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
 
 #include "QueryOptionsDlg.h"
 
-#include <kv_resource.h>
 
 #include <kstandarddirs.h>
-#include <klocale.h>
 #include <kdebug.h>
 #include <kapplication.h>
 #include <kcombobox.h>
 
-#include <qpixmap.h>
 
 
 #define Inherited QTabDialog
@@ -49,10 +44,20 @@ QueryOptionsDlg::QueryOptionsDlg
         int           mqtime,
         bool          showcounter,
         kvq_timeout_t type_timeout,
-        kvoctrainDoc *_doc,
+        kvoctrainDoc *,
         KComboBox    *lessons,
         QueryManager *_manager,
         bool          swapdir,
+        bool          suggestions,
+        bool          split,
+        bool          periods,
+        bool          colons,
+        bool          semicolons,
+        bool          commas,
+        int           fields,
+        bool          show_more,
+        bool          i_know,
+        bool          altlearn,
         bool          block,
         bool          expire,
         vector<PreSetting>  preset,
@@ -71,8 +76,8 @@ QueryOptionsDlg::QueryOptionsDlg
 
   groupOptPage = new GroupOptPage (settings, this, name);
   threshOptPage = new ThreshOptPage (&manager, lessons, this, name);
-  queryOptPage = new QueryOptPage (mqtime, showcounter, type_timeout, &manager,
-                                   swapdir, this, name);
+  queryOptPage = new QueryOptPage (mqtime, showcounter, type_timeout, &manager, swapdir,
+    suggestions, split, periods, colons, semicolons, commas, fields, show_more, i_know, altlearn, this, name);
   blockOptPage = new BlockOptPage (&manager, block, expire, this, name);
 
   addTab( groupOptPage, i18n("&Groups"));
@@ -100,8 +105,12 @@ QueryOptionsDlg::QueryOptionsDlg
   connect( this, SIGNAL(cancelButtonPressed()), SLOT(cancelButton()) );
 
   threshOptPage->slotBlockExpire (getBlock(), getExpire());
+}
 
-  setIcon (QPixmap (locate("data",  "kvoctrain/mini-kvoctrain.xpm" )));
+void QueryOptionsDlg::showEvent (QShowEvent* event)
+{
+  Inherited::showEvent (event);
+  resize (width(), minimumSize().height());
 }
 
 
@@ -141,17 +150,48 @@ void QueryOptionsDlg::slotSelectGroup(int grp)
     QString s;
     int mqtime = 0;
     bool swap = false;
+    bool altlearn = false;
     bool show = false;
     kvq_timeout_t type_to = kvq_notimeout;
+    bool suggestions = false;
+    bool split = false;
+    bool periods = true;
+    bool colons = false;
+    bool semicolons = true;
+    bool commas = false;
+    int  fields = 5;
+    bool show_more = true;
+    bool i_know = true;
     if (extract (line, s))
       mqtime = s.toInt();
     if (extract (line, s))
       swap = (bool) s.toInt();
+    if (extract (line, s))
+      altlearn = (bool) s.toInt();
     if (extract (line, s))
       show = (bool) s.toInt();
     if (extract (line, s))
       type_to = (kvq_timeout_t) s.toInt();
-    queryOptPage->setStates (mqtime, swap, show, type_to);
+    if (extract (line, s))
+      suggestions = (bool) s.toInt();
+    if (extract (line, s))
+      split = (bool) s.toInt();
+    if (extract (line, s))
+      periods = (bool) s.toInt();
+    if (extract (line, s))
+      colons = (bool) s.toInt();
+    if (extract (line, s))
+      semicolons = (bool) s.toInt();
+    if (extract (line, s))
+      commas = (bool) s.toInt();
+    if (extract (line, s))
+      fields = s.toInt();
+    if (extract (line, s))
+      show_more = (bool) s.toInt();
+    if (extract (line, s))
+      i_know = (bool) s.toInt();
+    queryOptPage->setStates (mqtime, swap, altlearn, show, type_to, suggestions,
+      split, periods, colons, semicolons, commas, fields, show_more, i_know);
 
 #define QCT(x)  QueryManager::CompType(x)
 
@@ -256,10 +296,30 @@ void QueryOptionsDlg::slotModifyGroup(int grp)
     line += s + ',';
     s.setNum(getSwapDir());
     line += s + ',';
+    s.setNum(getAltLearn());
+    line += s + ',';
     s.setNum((int) getShowCounter());
     line += s + ',';
     s.setNum( (int) getTypeQueryTimeout());
     line += s + ',';
+    s.setNum((int) getSuggestions());
+    line += s + ',';
+    s.setNum((int) getSplit());
+    line += s + ',';
+    s.setNum((int) getPeriods());
+    line += s + ',';
+    s.setNum((int) getColons());
+    line += s + ',';
+    s.setNum((int) getSemicolons());
+    line += s + ',';
+    s.setNum((int) getCommas());
+    line += s + ',';
+    s.setNum(getFields());
+    line += s + ',';
+    s.setNum((int) getShowMore());
+    line += s + ',';
+    s.setNum((int) getIKnow());
+    line += s + ',';
     settings[grp].query_set = line;
 
     line = '(' + manager.lessonItemStr() + ')';
@@ -293,7 +353,7 @@ void QueryOptionsDlg::slotModifyGroup(int grp)
       s.setNum(manager.blockItem(i));
       line += s + ',';
     }
-  
+
     s.setNum(getExpire());
     line += s + ',';
     for (int i = KV_LEV1_GRADE; i <= KV_MAX_GRADE; i++) {
